.. dungeonsheets documentation master file, created by
   sphinx-quickstart on Sun Oct 14 18:07:48 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Dungeonsheets's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   character_files
   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: ../README.rst
